/**
 * Copyright 2013 Facebook, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @providesModule copyProperties
 */

/**
 * Copy properties from one or more objects (up to 5) into the first object.
 * This is a shallow copy. It mutates the first object and also returns it.
 *
 * NOTE: `arguments` has a very significant performance penalty, which is why
 * we don't support unlimited arguments.
 */
function copyProperties(obj, a, b, c, d, e, f) {
    obj = obj || {};
    var args = [a, b, c, d, e];
    var ii = 0, v;

    while (args[ii]) {
      v = args[ii++];
      for (var k in v) {
        obj[k] = v[k];
      }

      // IE ignores toString in object iteration.. See:
      // webreflection.blogspot.com/2007/07/quick-fix-internet-explorer-and.html
      if (v.hasOwnProperty && v.hasOwnProperty('toString') &&
          (typeof v.toString != 'undefined') && (obj.toString !== v.toString)) {
        obj.toString = v.toString;
      }
    }

    return obj;
}

module.exports = copyProperties;
